#
# spec file for package noson-app
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           noson-app
Version:        4.2.6
Release:        bp153.1.22
Summary:        SONOS device controller
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://janbar.github.io/noson-app/index.html
Source0:        https://github.com/janbar/noson-app/archive/%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  flac-devel
BuildRequires:  gcc-c++
BuildRequires:  libopenssl-devel
BuildRequires:  libpulse-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(noson) = 2.3.0
Requires:       libqt5-qtgraphicaleffects
Requires:       libqt5-qtquickcontrols2

%description
A controller for SONOS devices. It allows for browsing the music
library, and playing tracks or radio on any zones. Zone groups,
queues and playlists can be managed, and playback be controlled.

%prep
%setup -q

%build
%cmake \
    -DCMAKE_BUILD_TYPE=Release \
    -DBUILD_DEPENDENCIES=OFF \
    -DBUILD_LIBNOSON=OFF
%make_jobs

%install
%make_install -C build
%suse_update_desktop_file -i io.github.janbar.noson Music

%if 0%{?suse_version} < 1330
%post
%desktop_database_post
%endif

%if 0%{?suse_version} < 1330
%postun
%desktop_database_postun
%endif

%files
%doc README.md
%license LICENSE
%{_bindir}/noson-app
%{_datadir}/applications/io.github.janbar.noson.desktop
%{_datadir}/icons/hicolor/
%{_datadir}/metainfo/io.github.janbar.noson.appdata.xml
%{_libdir}/noson/

%changelog
* Tue Mar 17 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add libqt5-qtgraphicaleffects and libqt5-qtquickcontrols2
  dependencies: those Qt5 extensions are required to start the
  application.
- Drop update-alternatives dependencies: u-a is not used at all
  here.
* Tue Jan 28 2020 Bo Simonsen <bosim@opensuse.org>
- Update to 4.2.6
  * Fix set volume on moved to handle wheel mouse on desktop
  * Fix resync track position after sleeping for the Sailfish app
  * Minor graphical improvements
* Sun Jan 19 2020 Bo Simonsen <bosim@opensuse.org>
- Update to 4.2.5
  * Fix on share index finished the library could not be reloaded
  * Minor graphical improvements for the Sailfish app
* Thu Jan 16 2020 Bo Simonsen <bosim@opensuse.org>
- Update to 4.2.4
  * Minor fixes
  * Update translations for 4.2.0
  * All controls are asynchonous
  * Fix for playlist editing (drag/move and delete)
  * Preview release for SailfishOS 3.2 using native framework
    Silica 1.0
  * GUI improvements and cleanup
  * Better dragging of volumes (multi zones)
* Sun Dec 15 2019 Bo Simonsen <bosim@opensuse.org>
- Update to 4.1.0
  * Allow to seek position for local file (also it fixes the
    pause/play for local files)
  * Allow to stream local media m4a
  * Improves the GUI performances
  * Minor fixes
- Add %%license and %%doc to spec file
* Sun Dec 15 2019 Bo Simonsen <bosim@opensuse.org>
- Update to 4.0.2
  * Fix cover url for local media files
  * Minor fixes
  * Review the music row design
  * Fix performance issue using MPRIS2 (The service bumps the app
    for the current position)
  * Sync upstream libnoson (2.0.0)
  * Fix double path in the service stack page
  * Supports the MPRIS2 interface for player
  * Allow to bypass the SSDP discovery by passing the url of a
    SONOS device
  * Fix missing search categories for the services without
    presentation map
  * Fix a bug in service registration (PocketCasts and probably
    few others)
  * Enable loudness setting
  * Workaround Spotify BUG using locale en_GB
  * Support for output fixed
  * Minor fixed and improvements
  * Fix for ID3 parser
  * Minor fixes
  * Improve the ogg parser
  * Update translations for nl
  * Minor improvements
  * Add support for media file with the format OGG/Vorbis
  * Fix language range to be compliant with RFC-4647 (Issue with
    Spotify services)
  * Fix SSL handshake on old android platforms
  * Show the logo of the thumbnails providers to comply with their
    guidelines
  * Fetch thumbnails from DEEZER by default
  * Improvements: libnoson 1.13.2
  * Use multicast UDP packet as fallback when discovering
  * Fix to work around multicast filtering when discovering devices
  * Minor fixes
* Sat Apr  6 2019 bosim@opensuse.org
- Pulseaudio support
* Sat Apr  6 2019 bosim@opensuse.org
- Update to 3.11.4
  * Fix Sonos API change in build 49263270 (10.1)
  * Improve the fluency of the volume control for a zone.
  * Use smaller step for the volume control: The wheel mouse still
    works.
  * Play a service item by clicking a button "play" instead the
    item itself.
  * Improve threading of the media scanner
  * Includes a media scanner for audio files. Types supported are
    FLAC, MP3 and AAC.
  * It streams local audio files.
  * It streams the pulseaudio output
* Mon Jan 21 2019 bosim@opensuse.org
- Update to 3.9.7
  * Port away from deprecated API
  * Fix getting initial sound settings
  * Minor UI fixes
  * Show more in song info
  * Using customized footer in dialogs
  * Enable wheel mouse to slide volume, and make it smoothest
  * Improve zone connection on topology changed
  * Fix SNI issue with OpenSSL
  * Add support for language Danish
  * Fix origin for icon rotation
  * Show overlay during update of share index
  * Fix keyboard input methods for Android 7.0 (Nougat) and upper
  * Disable keyboard input when search field is hidden
* Wed Aug  8 2018 jengelh@inai.de
- Try improving description grammar.
* Fri Aug  3 2018 bosim@opensuse.org
- Update to 3.7.0
- Removed _service file and added source URL
- Use cmake-directories to avoid static linking of libnoson
* Sat Jul 21 2018 bosim@opensuse.org
- Updated to 3.6.4
- Ran spec-cleaner
* Thu Jul  5 2018 bosim@opensuse.org
- Updated to 3.6.3
- Package now depend on libnoson1
- Removed patch (fixed upstream)
* Sat Jun 30 2018 bosim@opensuse.org
- Initial package
